searchData={"items":[{"type":"behaviour","title":"Drill","doc":"Drill is an elixir seeder library inspired by [Seed Fu](https://github.com/mbleigh/seed-fu) and [Phinx](https://github.com/cakephp/phinx).","ref":"Drill.html"},{"type":"behaviour","title":"Usage - Drill","doc":"1. Create your seeder modules. The directory where the seeder modules should be located\n is described on [mix drill documentation](https://hexdocs.pm/drill/Mix.Tasks.Drill.html).\n\nIn `my_app/priv/repo/seeds/user.exs`:\n\n```\ndefmodule MyApp.Seeds.User do\n  use Drill, key: :users, source: MyApp.Accounts.User\n\n  def factory do\n    %{\n      first_name: Person.first_name(),\n      last_name: Person.last_name()\n    }\n  end\n\n  def run(_context) do\n    [\n      seed(email: \"email1@example.com\"),\n      seed(email: \"email2@example.com\"),\n      seed(email: \"email3@example.com\")\n    ]\n  end\nend\n```\n\nIn `my_app/priv/repo/seeds/post.exs`:\n\n```\ndefmodule MyApp.Seeds.Post do\n  use Drill, key: :posts, source: MyApp.Blogs.Post\n  alias Faker.Lorem\n\n  def deps do\n    [MyApp.Seeds.User]\n  end\n\n  def factory do\n    %{content: Lorem.paragraph()}\n  end\n\n  def run(%Drill.Context{seeds: %{users: [user1, user2, user3 | _]}}) do\n    [\n      seed(user_id: user1.id),\n      seed(user_id: user2.id),\n      seed(user_id: user3.id)\n    ]\n  end\nend\n```\n\n2. Run `mix drill -r MyApp.Repo` in the terminal with your project root as the current working directory","ref":"Drill.html#module-usage"},{"type":"behaviour","title":"Installation - Drill","doc":"Add `drill` to your list of dependencies in `mix.exs`:\n```\ndef deps do\n  [\n    {:drill, \"~> 1.2\"}\n  ]\nend\n```","ref":"Drill.html#module-installation"},{"type":"behaviour","title":"Configurations - Drill","doc":"","ref":"Drill.html#module-configurations"},{"type":"behaviour","title":"Timeout - Drill","doc":"Default timeout is 600 seconds or 10 minutes. You may configure the task timeout in your config.exs file e.g.:\n  config :drill, :timeout, 10_000\n\n## `use Drill` options\n* `source` (required) - source is the schema module\n* `key` (required) - once the seeder module runs, the inserted result will be saved to `%Drill.Context{}.seeds[key]`.\nDrill.Context struct is passed to one of Drill's callback which is `run/1` to be discussed in the `Callbacks`\nsection below.\n* `returning` (optional) - selects which fields to return. Defaults to true. See [Ecto.Repo.insert_all/3](https://hexdocs.pm/ecto/Ecto.Repo.html#c:insert_all/3)","ref":"Drill.html#module-timeout"},{"type":"behaviour","title":"Callbacks - Drill","doc":"* `constraints/0` (optional) - returns a list of column names to verify for conflicts. If a conflict occurs all fields will\njust be updated. This prevents insertion of new records based on the constraints when drill is run again.\n* `on_conflict/0` (optional) - returns the conflict strategy. The default is `:replace_all`. Only works when `constraints/0`\nreturns a non-empty list. See [Ecto.Repo.insert_all/4](https://hexdocs.pm/ecto/Ecto.Repo.html#c:insert_all/4) for more details.\n* `deps/0` (optional) - returns a list of seeder modules that should be run prior to the current seeder\n* `factory/0` (optional) - set default values for the fields. This is used when you call `seed/1` from the seeder module.\n* `run/1` (required) - returns a list of seeds (a call to `Drill.seed/1` function or anything you want to include in the context seed).\nAutogenerated fields such as `:inserted_at` or `:updated_at` may not be defined. The first argument is the `Drill.Context` struct, which\nyou can use to get the inserted records from previously run seeder modules (see Usage section above).","ref":"Drill.html#module-callbacks"},{"type":"behaviour","title":"Command line options - Drill","doc":"* `--repo` - specifies the repository to use\n* `--seeds-path` - overrides the default seeds path\n* Command line options for `mix app.start` documented [here](https://hexdocs.pm/mix/1.15.2/Mix.Tasks.App.Start.html#module-command-line-options)","ref":"Drill.html#module-command-line-options"},{"type":"callback","title":"Drill.constraints/0","doc":"","ref":"Drill.html#c:constraints/0"},{"type":"callback","title":"Drill.deps/0","doc":"","ref":"Drill.html#c:deps/0"},{"type":"callback","title":"Drill.factory/0","doc":"","ref":"Drill.html#c:factory/0"},{"type":"callback","title":"Drill.on_conflict/0","doc":"","ref":"Drill.html#c:on_conflict/0"},{"type":"callback","title":"Drill.run/1","doc":"","ref":"Drill.html#c:run/1"},{"type":"module","title":"Drill.Context","doc":"Seed struct containing all inserted items as seeds","ref":"Drill.Context.html"},{"type":"type","title":"Drill.Context.t/0","doc":"","ref":"Drill.Context.html#t:t/0"},{"type":"module","title":"Drill.Seed","doc":"Contains helper and struct definition for seeds","ref":"Drill.Seed.html"},{"type":"function","title":"Drill.Seed.new/2","doc":"","ref":"Drill.Seed.html#new/2"},{"type":"type","title":"Drill.Seed.t/0","doc":"","ref":"Drill.Seed.html#t:t/0"},{"type":"module","title":"Drill.Seeder","doc":"Module responsible for seeding data into the database","ref":"Drill.Seeder.html"},{"type":"function","title":"Drill.Seeder.autogenerate_fields/1","doc":"","ref":"Drill.Seeder.html#autogenerate_fields/1"},{"type":"function","title":"Drill.Seeder.build_entries_from_seeds/1","doc":"","ref":"Drill.Seeder.html#build_entries_from_seeds/1"},{"type":"function","title":"Drill.Seeder.filter_manual_seeds/1","doc":"","ref":"Drill.Seeder.html#filter_manual_seeds/1"},{"type":"function","title":"Drill.Seeder.list_seeder_modules/1","doc":"","ref":"Drill.Seeder.html#list_seeder_modules/1"},{"type":"function","title":"Drill.Seeder.seeders_path/2","doc":"","ref":"Drill.Seeder.html#seeders_path/2"},{"type":"module","title":"Drill.Utils","doc":"Utilities and helpers","ref":"Drill.Utils.html"},{"type":"function","title":"Drill.Utils.merge_autogenerated_fields_to_entries/2","doc":"","ref":"Drill.Utils.html#merge_autogenerated_fields_to_entries/2"},{"type":"function","title":"Drill.Utils.sort_seeders_by_deps/1","doc":"Sort seeder modules by dependencies. Seeders without deps are put first in the list,\nnext to seeders with deps already in the list, and so on...","ref":"Drill.Utils.html#sort_seeders_by_deps/1"},{"type":"task","title":"mix drill","doc":"Runs all seeder modules under \"priv/YOUR_REPO/seeds. Needs the Repo as an argument.\n    $ mix drill -r MyApp.Repo\n\nSetting seeds directory is similar to [Ecto migration](https://hexdocs.pm/ecto_sql/Mix.Tasks.Ecto.Migrate.html),\n1. \"YOUR_REPO\" is the last segment in your repository name. E.g. MyApp.MyRepo will use\n\"priv/my_repo/seeds\".\n2. You can configure a repository to use another directory by specifying the :priv key under the repository configuration.\nThe \"seeds\" part will be automatically appended to it. For instance, to use \"priv/custom_repo/seeds\":\n    config :my_app, MyApp.Repo, priv: \"priv/custom_repo\"\n3. You can also set the directory by adding the following to your config:\n    config :drill, :directory, \"seeds\"\n4. Lastly, you can override the path of the seeds directory by passing the --seeds-path option:\n    $ mix drill -r MyApp.Repo --seeds-path priv/custom_repo/seeds","ref":"Mix.Tasks.Drill.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,50,46,49]}}